@@ -13,7 +13,7 @@
 ##############################################################################
 """File interfaces
 
-$Id: interfaces.py 90989 2008-09-09 09:37:27Z nadako $
+$Id: interfaces.py 92392 2008-10-20 08:37:13Z nadako $
 """
 __docformat__ = 'restructuredtext'
 
@@ -25,10 +25,13 @@ class IOpenable(zope.interface.Interface):
     """Openable file
     """
 
-    def open(mode):
+    def open(mode='r'):
         """Open file and return the file descriptor
         """
 
+    def openDetached():
+        '''Return a read-only file descriptor, detached from ZODB connection'''
+
 class IBlobFile(zope.app.file.interfaces.IFile, IOpenable):
     """A file that uses Blobs as data storage."""
 
